@@ -628,7 +628,7 @@ def test_diff(test_obj, storage1, storage2):
     time.sleep(0.1)
     group_str2 = test_obj.create_test_group_name(storage2)
     #
-    (message_dict_message_dict_tuple_list, message_counter_int1, message_counter_int2) = storage1.diff(topic_str1, storage2, topic_str2, group1=group_str1, group2=group_str2, type1="json", type2="json", n=3, consume_batch_size=3)
+    (message_dict_message_dict_tuple_list, message_counter_int1, message_counter_int2) = storage1.diff(topic_str1, storage2, topic_str2, source1_group=group_str1, source2_group=group_str2, source1_type="json", source2_type="json", n=3, consume_batch_size=3)
     test_obj.assertEqual(3, len(message_dict_message_dict_tuple_list))
     test_obj.assertEqual(3, message_counter_int1)
     test_obj.assertEqual(3, message_counter_int2)
@@ -649,12 +649,12 @@ def test_from_to_file(test_obj, storage1, storage2):
         #
         group_str1 = test_obj.create_test_group_name(storage1)
         file_str = f"{topic_str1}{suffix_str}"
-        n_int1 = storage1.to_file(topic_str1, storage2, file_str, group=group_str1, type="json")
+        n_int1 = storage1.topic_to_file(topic_str1, storage2, file_str, group=group_str1, type="json")
         test_obj.assertTrue(n_int1, 3)
         #
         topic_str2 = test_obj.create_test_topic_name(storage1)
         storage1.create(topic_str2)
-        storage1.from_file(storage2, file_str, topic_str2)
+        storage2.file_to_topic(file_str, storage1, topic_str2)
         #
         group_str2 = test_obj.create_test_group_name(storage1)
         message_dict_list = storage1.cat(topic_str2, group=group_str2, n=3, type="json")
