@@ -24,8 +24,8 @@ class Test(TestSingleStorageBase):
 #
 
     def get_storage(self):
-        # c = Cluster("local")
-        c = Cluster("local_redpanda")
+        c = Cluster("local")
+        # c = Cluster("local_redpanda")
         # c = Cluster("ccloud") # also set self.principal_str above if testing against Confluent Cloud
         #
         return c
